@@ -1,16 +1,17 @@
 package Chrome::DevToolsProtocol::Transport::NetAsync;
 use strict;
 use Moo 2;
-use Filter::signatures;
 no warnings 'experimental::signatures';
 use feature 'signatures';
 use Scalar::Util 'weaken';
 use IO::Async::Loop;
 
+with 'MooX::Role::EventEmitter';
+
 use Net::Async::WebSocket::Client;
 Net::Async::WebSocket::Client->VERSION(0.12); # fixes some errors with masked frames
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 
 =head1 NAME
 
@@ -46,6 +47,7 @@ sub connect( $self, $handler, $got_endpoint, $logger ) {
     $logger ||= sub{};
     weaken $handler;
 
+    weaken( my $s = $self );
     my $client;
     $got_endpoint->then( sub( $endpoint ) {
         $client = Net::Async::WebSocket::Client->new(
@@ -60,6 +62,9 @@ sub connect( $self, $handler, $got_endpoint, $logger ) {
                 my( $connection )=@_;
                 $logger->('info', "Connection closed");
                 # TODO: should we tell handler?
+
+                $s->emit('closed')
+                    if( $s );
             },
         );
 
